---
jupyter:
  jupytext:
    text_representation:
      extension: .md
      format_name: markdown
---

# API Reference

## Oct2Py

::: oct2py.Oct2Py

## OctaveWorkspaceProxy

::: oct2py.OctaveWorkspaceProxy

## Struct

::: oct2py.Struct

## Cell

::: oct2py.Cell

## StructArray

::: oct2py.StructArray

## Oct2PyError

::: oct2py.Oct2PyError

## Oct2PyWarning

::: oct2py.Oct2PyWarning

## get_log

::: oct2py.get_log

## kill_octave

::: oct2py.kill_octave

## Oct2PySettings

::: oct2py.Oct2PySettings

## configure

::: oct2py.configure
